AppLightColors class abstract
Цвета светлой темы модуля темизации SeedKit
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- backgroundPage → const Color
- backgroundSurface1 → const Color
- backgroundSurface2 → const Color
- backgroundSurface3 → const Color
- backgroundSurface4 → const Color
- backgroundSurface5 → const Color
- borderDefault → const Color
- borderLight → const Color
- borderMuted → const Color
- containerDefault → const Color
- contentDefault → const Color
- contentDisabled → const Color
- contentLight → const Color
- contentMuted → const Color
- errorDefault → const Color
- infoDefault → const Color
- neutralActive → const Color
- neutralDefault → const Color
- primaryDefault → const Color
- status1Default → const Color
- status2Default → const Color
- status3Default → const Color
- status4Default → const Color
- status5Default → const Color
- status6Default → const Color
- successDefault → const Color
- warningDefault → const Color
- warningLight → const Color