SeedKitTextTheme class

Реализация шрифтов ThemeExtension для ThemeData.extensions

Inheritance

Constructors

SeedKitTextTheme({required TextStyle captionLarge, required TextStyle captionMedium, required TextStyle captionSmall, required TextStyle displayLarge, required TextStyle displaySmall, required TextStyle heading1, required TextStyle heading2, required TextStyle heading3, required TextStyle heading4, required TextStyle heading5, required TextStyle heading6, required TextStyle paragraphLarge, required TextStyle paragraphMedium, required TextStyle paragraphSmall, required TextStyle paragraphXSmall, required TextStyle paragraphXSSmall})
const
SeedKitTextTheme.withColor(Color? color)
Констурктор с применением темизации к шрифтам

Properties

captionLarge TextStyle
final
captionMedium TextStyle
final
captionSmall TextStyle
final
displayLarge TextStyle
final
displaySmall TextStyle
final
hashCode int
The hash code for this object.
no setterinherited
heading1 TextStyle
final
heading2 TextStyle
final
heading3 TextStyle
final
heading4 TextStyle
final
heading5 TextStyle
final
heading6 TextStyle
final
paragraphLarge TextStyle
final
paragraphMedium TextStyle
final
paragraphSmall TextStyle
final
paragraphXSmall TextStyle
final
paragraphXSSmall TextStyle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Object
The extension's type.
no setterinherited

Methods

copyWith() ThemeExtension<SeedKitTextTheme>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<SeedKitTextTheme>? other, double t) ThemeExtension<SeedKitTextTheme>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited