StaticTextTheme class abstract

Шрифты модуля темизации SeedKit

Constructors

StaticTextTheme()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

captionLarge TextStyle
no setter
captionMedium TextStyle
no setter
captionSmall TextStyle
no setter
displayLarge TextStyle
no setter
displaySmall TextStyle
no setter
fontFamily String
getter/setter pair
heading1 TextStyle
no setter
heading2 TextStyle
no setter
heading3 TextStyle
no setter
heading4 TextStyle
no setter
heading5 TextStyle
no setter
heading6 TextStyle
no setter
paragraphLarge TextStyle
no setter
paragraphMedium TextStyle
no setter
paragraphSmall TextStyle
no setter
paragraphXSmall TextStyle
no setter
paragraphXSSmall TextStyle
no setter