ThemeRepository class

Constructors

ThemeRepository(ThemeProvider _localDataProvider)

Properties

getThemeMode ThemeMode
no setter
getThemeStream Stream<ThemeMode>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveTheme([ThemeMode? theme]) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited