StaticColors class abstract
Общие цвета модуля темизации SeedKit
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- primaryColor ↔ Color
-
getter/setter pair
Constants
- backgroundOverlay → const Color
- black → const Color
- blue → const Color
- green → const Color
- shadow → const Color
- stickerBlue → const Color
- stickerBlueDark → const Color
- stickerGreen → const Color
- stickerGreenDark → const Color
- stickerPink → const Color
- stickerPinkDark → const Color
- stickerYellow → const Color
- stickerYellowDark → const Color
- transparent → const Color
- white → const Color
- yellow → const Color